import os
from glob import glob
from setuptools import setup
from setuptools.command.install import install
from ls2n_drone_command_center.trajectory_generator import generate_trajectories

class GenerateTrajectories(install):
    def run(self):
        install.run(self)
        generate_trajectories()


package_name = "ls2n_drone_command_center"
submodule = f"{package_name}/utilities"

setup(
    name=package_name,
    version="0.1.0",
    packages=[package_name, submodule],
    data_files=[
        (
            "share/ament_index/resource_index/packages",
            ["resource/" + package_name],
        ),
        ("share/" + package_name, ["package.xml"]),
        (os.path.join("share", package_name), glob("launch/*.launch.py")),
        (
            os.path.join("share", package_name),
            glob("ls2n_drone_command_center/*.py"),
        ),
        (
            os.path.join("share", package_name, "config"),
            glob("config/*.yaml"),
        ),
        (
            os.path.join('share', package_name, 'trajectories'),
            glob('trajectories/*.traj')
        ),
    ],
    install_requires=["setuptools"],
    zip_safe=True,
    maintainer="Damien Six",
    maintainer_email="damien.six@ls2n.fr",
    description="A package containing the tools required to remotely control one or several drones at the LS2N "
    "laboratory.",
    license="Apache 2.0",
    tests_require=["pytest"],
    entry_points={
        "console_scripts": [
            "joystick = ls2n_drone_command_center.joystick_connect:main",
            "trajectory_publisher = ls2n_drone_command_center.trajectory_publisher:main",
            "qualisys = ls2n_drone_command_center.qualisys_bridge:main",
            "multi_control = ls2n_drone_command_center.multi_control:main",
            'generate_trajectories = ls2n_drone_command_center.trajectory_generator:generate_trajectories',
            'list_trajectories = ls2n_drone_command_center.trajectory_generator:list_trajectories',
            'plot_trajectory = ls2n_drone_command_center.trajectory_generator:plot_trajectory',
        ],
    },
    cmdclass={'install': GenerateTrajectories}
)
